# Xpra Sponsors


[Xpra-org](https://github.com/Xpra-org) relies on its sponsors for the development and support of its software releases.  
This funding is critical to the success of the project, including all the hardware needed for development, build and testing.  

If your business uses xpra, please consider sponsoring the project or becoming a business partner.  
By participating in the project's management, you can ensure that it continues to grow in a direction that aligns with your business goals.  
Having a direct line of communication has helped all the sponsors in getting the most out of their solutions.  
Sponsors also get priority support and timely issue resolution.  


## Supporters

We value each and every donation we receive.  
You can send small contributions directly to the [project administrator](https://github.com/sponsors/totaam), every little bit helps.  
For hardware donations or sponsorship, please contact [xpra@xpra.org](mailto:xpra@xpra.org).


## Sponsors List

| Company                                                                                                    | From | To   | About                                                                                                                                                                            |
|------------------------------------------------------------------------------------------------------------|------|------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Anonymous                                                                                                  | 2012 | 2020 | Web security and isolation                                                                                                                                                       |
| [![Atos HPC](./images/logos/atos-black.png)](https://atos.net/en/solutions/high-performance-computing-hpc) | 2012 |      | _"Designing the future of the digital space"._<br />_"A leader in cloud and digital workplace, Atos is also ranked #1 in managed security services worldwide by revenue (2021)"_ |
| [![VPO](./images/logos/vpo-small.png)](https://vpo.nl)                                                     | 2020 |      | _"We set the tone for a new (IT) culture of freedom and trust by embracing and sharing exceptional openness"._                                                                   |
